Export Package VRC : bcB40Mc4mcr0
Update compared VRC:   B40Mc4ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : Yes
Function  sources  : No
Library sources    : Yes
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
dbcmcr.ctyp                         B40Mc4mcr0
tbcsci002                           B40Mc4mcr0
pbcintdll0000                       B40Mc4mcr0 (with source)
pbcintdll0005                       B40Mc4mcr0 (with source)
bbcint0005                          B40Mc4mcr0 (without source)
obcintdll0000                       B40Mc4mcr0
obcintdll0005                       B40Mc4mcr0
